@@ -1,6 +1,6 @@
 package org.apache.maven.shared.artifact.filter.collection;
 
-/*
+/* 
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -16,25 +16,30 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License. 
+ * under the License.    
  */
 
-import java.util.HashSet;
+import java.util.LinkedHashSet;
 import java.util.Set;
 
 import org.apache.maven.artifact.Artifact;
 
+/**
+ * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
+ * @version $Id: AbstractArtifactsFilter.java 1716978 2015-11-28 14:47:04Z khmarbaise $
+ */
 public abstract class AbstractArtifactsFilter
     implements ArtifactsFilter
 {
     /**
-     * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
-     * @version $Id: AbstractArtifactsFilter.java 661727 2008-05-30 14:21:49Z bentmann $
-     * @throws ArtifactFilterException 
+     * @param artifact {@link Artifact}
+     * @return {@code true} if artifact is includes {@code false} otherwise.
+     * @throws ArtifactFilterException when filtering fails
      */
-    public boolean isArtifactIncluded( Artifact artifact ) throws ArtifactFilterException
+    public boolean isArtifactIncluded( Artifact artifact )
+        throws ArtifactFilterException
     {
-        Set set = new HashSet();
+        Set<Artifact> set = new LinkedHashSet<Artifact>();
         set.add( artifact );
 
         set = filter( set );
